@@ -2,9 +2,9 @@ var searchData=
 [
   ['harden_0',['harden',['../a00974.html#a95da3cc077feb8d7b244871a8ac7a925',1,'_uno_Environment']]],
   ['has_1',['has',['../a01962.html#a06c455cfa3f0d537503427c53afc2045',1,'com::sun::star::uno::Any']]],
-  ['haselements_2',['hasElements',['../a01010.html#ae0691df9c7c72a5636ffb29db04769c6',1,'com::sun::star::uno::Sequence']]],
-  ['hashcode_3',['hashCode',['../a00666.html#aa2a34f4f40619c75d799b21e5faf863b',1,'rtl::OString::hashCode()'],['../a00754.html#a44b729dfde7f37da377511cbf6d4cbfe',1,'rtl::OUString::hashCode()']]],
-  ['hashcode_4',['HashCode',['../a00650.html#af2d4eb053e59e20cbceef897c579c5ff',1,'_rtl_Locale']]],
+  ['haselements_2',['hasElements',['../a01010.html#ae0691df9c7c72a5636ffb29db04769c6',1,'com::sun::star::uno::Sequence::hasElements()'],['../a01010.html#ae0691df9c7c72a5636ffb29db04769c6',1,'com::sun::star::uno::Sequence&lt; bool &gt;::hasElements()']]],
+  ['hashcode_3',['HashCode',['../a00650.html#af2d4eb053e59e20cbceef897c579c5ff',1,'_rtl_Locale']]],
+  ['hashcode_4',['hashCode',['../a00666.html#aa2a34f4f40619c75d799b21e5faf863b',1,'rtl::OString::hashCode()'],['../a00754.html#a44b729dfde7f37da377511cbf6d4cbfe',1,'rtl::OUString::hashCode()']]],
   ['hashint32_5fimpl_5',['hashInt32_Impl',['../a01910.html',1,'cppu']]],
   ['hashtype_5fimpl_6',['hashType_Impl',['../a01878.html',1,'cppu']]],
   ['hasmoreelements_7',['hasMoreElements',['../a01858.html#a91cc5fbc572c3ab44c0dc455a06b90cf',1,'cppu::OInterfaceIteratorHelper']]],
@@ -12,6 +12,6 @@ var searchData=
   ['haspropertybyname_9',['hasPropertyByName',['../a01898.html#a4f6cece15cb2a08270277c138a0fce30',1,'cppu::IPropertyArrayHelper::hasPropertyByName()'],['../a01902.html#ac54e800f7e420eef0dbbff7ed14a5e1a',1,'cppu::OPropertyArrayHelper::hasPropertyByName()']]],
   ['hasvalue_10',['hasValue',['../a01962.html#a3f26c338b55b3329abd47bb5d5e3565b',1,'com::sun::star::uno::Any']]],
   ['heapusage_11',['HeapUsage',['../a00838.html#ace32f2e90839d91618fb0acac68a22af',1,'oslProcessInfo']]],
-  ['here_12',['here',['../a00296.html#a7ff658547cb9dc2b7df61e47c4b79880',1,'lbnames.h']]],
+  ['here_12',['here',['../a00287.html#a7ff658547cb9dc2b7df61e47c4b79880',1,'lbnames.h']]],
   ['hours_13',['Hours',['../a00890.html#a4f428140e51e3e208472e482a514593f',1,'_oslDateTime']]]
 ];
